#include "Assertion\Assertion.as"

const uint MAX_TEST_COUNT = 1000;
const uint TEST_STEP_COUNT = 70;

void main()
{
	Init();
	
	for (uint i = 1; i <= MAX_TEST_COUNT; i++)
	{
		TestStep(i);
	}
	
	CleanUp();
}

void TestStep(uint stepNum)
{
	Trace("Starting test #" + stepNum + "\r\n");
	RandomizeNet();
	TeachStep(TEST_STEP_COUNT);
	while (IsTeaching())
	{
		SleepExec(50);
	}
	uint slot = GetLastTeacherAutoCaptureStockSlot();
	ASSERT(slot > 0, "No valid stock slot to load net from!");
	ASSERT(LoadNetFromStock(slot), "Failed to load net from stock slot # " + slot);
	double err1 = GetNetError();
	EvaluateNetError();
	double err2 = GetNetError();
	string str1 = err1;
	string str2 = err2;
	
	Trace("Net Errors: err1 = " + str1 +  " - err2 = " + str2 + "\r\n");
				
	if (str1 != str2)
	{
		Trace("Error in net error calculation vs saved net from stock!\r\n");
		AbortScript();
	}
}

void Init()
{
	OpenNet("testnet1.mbn");
	SetLessonCount(2);
	SelectLesson(2);
	LoadLesson("Test2.mbl");
	SelectLesson(1);
	LoadLesson("Test1.mbl");
	SelectNetErrLesson(2);
	ASSERT(EnableScriptedElements("ScriptedEl.as"), "Failed to enable scripted elements");
	SetNetComparisonMethod(NET_COMP_NET_ERR); 				//Stock Capture by smallest NetError
	ASSERT(ConfigureNetErrorFunction(PATT_SUM_USR, NET_ERR_USR), "Failed to configure net error function");
	ClearStock();
	SetCaptureBestNetOnStock(true);
	// This speeds up processsing
    ViewSetting(UPDATE_TEACH, false);
    ViewSetting(UPDATE_THINK, false);
	
	ClearTraceWin();
}

void CleanUp()
{
	StopTeaching();
	SetCaptureBestNetOnStock(false);
	ConfigureNetErrorFunction(PATT_SUM_SQUARED, NET_ERR_ROOT_MEAN);
	DisableScriptedElements();
	ViewSetting(UPDATE_TEACH, true);
    ViewSetting(UPDATE_THINK, true);
}

void OnAbortScript()
{
	CleanUp();
}